<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt 壓縮程式&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>簡潔且不限桌面環境的 Qt 檔案壓縮程式</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>開發者：
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt 壓縮程式基於以下兩個軟體：
* MATE 桌面環境的 Engrampa 壓縮程式
* GNOME 桌面環境的 File Roller
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>授權</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="unfinished">LXQt 壓縮程式

版權 (C) 2018 LXQt 團隊

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. {2020 ?} {2
?} {51 ?} {02110-1301,?}</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>不支援該壓縮檔格式。</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 檔案 (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>所有支援的格式</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>無法執行此命令.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>找不到指令。</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>命令異常結束。</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>密碼為必須項目。</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>儲存區遺失。</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>損壞的字元集。</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>不支援的檔案格式。</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>發生未知錯誤。</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>將檔案拆成比較小的部份</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>密碼:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>檔案清單也加密</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>所有檔案 (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>解壓縮</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>解壓縮所有檔案(&amp;X)</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>解壓縮選取的檔案(&amp;T)</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>重新建立目錄</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>覆寫已經存在的檔案</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>不解壓縮比較舊的檔案</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="12"/>
        <source>All files (*)</source>
        <translation>所有檔案 (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>File Archiver</source>
        <translation>檔案壓縮程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>篩選檔案...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>&amp;View</source>
        <translation>檢視(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>&amp;Icon Size</source>
        <translation>圖示大小(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Main Toolbar</source>
        <translation>主選單列</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&amp;New</source>
        <translation>新增(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>Save &amp;As</source>
        <translation>另存新檔(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Ctrl+Shift+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&amp;Extract</source>
        <translation>解壓縮(E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>&amp;Test</source>
        <translation>測試(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="246"/>
        <source>&amp;Properties</source>
        <translation>屬性(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="249"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="258"/>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Cu&amp;t</source>
        <translation>剪下(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&amp;Copy</source>
        <translation>複製 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <source>&amp;Paste</source>
        <translation>貼上(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="302"/>
        <source>&amp;Rename</source>
        <translation>重新命名(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>&amp;Delete</source>
        <translation>刪除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>&amp;Select All</source>
        <translation>全選(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>&amp;Find</source>
        <translation>尋找(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>&amp;Add Files</source>
        <translation>加入檔案(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="350"/>
        <source>Add F&amp;older</source>
        <translation>加入資料夾(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Pass&amp;word</source>
        <translation>密碼(&amp;W)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="366"/>
        <source>&amp;Toolbar</source>
        <translation>工具列(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>&amp;Statusbar</source>
        <translation>狀態列(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Directory Tree</source>
        <translation>目錄樹(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="399"/>
        <source>S&amp;how as Folder</source>
        <translation>顯示成資料夾(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <source>Ctrl+Shift+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>Show &amp;All Files</source>
        <translation>顯示所有檔案(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Ctrl+Shift+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>St&amp;op</source>
        <translation>停止(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>Esc</source>
        <translation>退出(Esc)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>&amp;Reload</source>
        <translation>重新讀取(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Filename &amp;Encoding</source>
        <translation>檔案名稱編碼(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>&amp;View Selected Items</source>
        <translation>檢視所選項目(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>&amp;Filter</source>
        <translation>篩選(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Expand</source>
        <translation>展開 (&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="462"/>
        <source>Ctrl+Shift+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <source>Ctrl+Shift+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>&amp;Collapse</source>
        <translation>折疊 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>16 px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="489"/>
        <source>24 px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>32 px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="505"/>
        <source>48 px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>All files (*)</source>
        <translation>所有檔案 (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Add only if &amp;newer</source>
        <translation>只新增比較新的檔案(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Confirm</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>你確定要刪除選取的檔案?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Version: %1</source>
        <translation>版本: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>%p %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>No errors have been found.</source>
        <translation>未發現錯誤.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="912"/>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>N/A</source>
        <translation>不可用</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1001"/>
        <source>Uncompressed Size:</source>
        <translation>壓縮前大小:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>Compression Ratio:</source>
        <translation>壓縮比率:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1058"/>
        <source>File name</source>
        <translation>檔案名稱</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1059"/>
        <source>File Type</source>
        <translation>檔案類型</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1060"/>
        <source>File Size</source>
        <translation>檔案大小</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1061"/>
        <source>Modified</source>
        <translation>修改</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1062"/>
        <source>Encrypted</source>
        <translation>加密</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1088"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n 個檔案</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>加密檔案清單</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>顯示密碼</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;注意:&lt;/b&gt; 這個密碼會被用來加密你加入這個壓縮檔的檔案，以及用來解密你從目前壓縮檔解壓縮的檔案。當這個壓縮檔案被關閉，密碼將會被刪除&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>進度</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation>7-Zip (.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>使用 7z 壓縮的 Tar 檔案 (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation>Ace (.ace) 檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation>Ar (.a)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation>Ar (.ar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation>Arj (.arj) 檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>使用 bzip2 壓縮的 Tar 檔案 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>使用 bzip 壓縮的 Tar (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation>Cabinet (.cab) 檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>使用 RAR 封存的漫畫書 (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>使用 ZIP 封存的漫畫書 (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>使用 gzip 壓縮的 Tar (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation>Ear (.ear) 檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>自解壓 ZIP (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation>Jar (.jar) 檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation>Lha (.lzh) 檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation>Lrzip (.lrz) 檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>使用 lrzip 壓縮的 Tar (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>使用 lzip 壓縮的 Tar (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>使用 lzma 壓縮的 Tar (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>使用 lzop 壓縮的 Tar (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>Windows 鏡像格式 (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation>Rar (.rar) 檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>未壓縮 Tar (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>使用 compress 壓縮的 Tar (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation>War (.war)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation>Xz (.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>使用 xz 壓縮的 Tar (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>使用 zstd 壓縮的 Tar 檔案 (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation>Zoo (.zoo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation>Zip (.zip)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>正在加入檔案: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>正在解壓縮檔案: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation>%d %B %Y, %H:%M</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>正在移除檔案: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>從壓縮檔刪除</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>重新壓縮檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>正在解壓縮檔案</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>找不到檔案。</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>壓縮檔案格式不支援。</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>找不到壓縮檔</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>沒有正確權限。</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>這個類型的壓縮檔不能被修改</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>不能把壓縮檔加入到它自己。</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>找不到檔案分片: %s</translation>
    </message>
</context>
</TS>
